//  _____         _  _____
// |_   _|____  _| ||_   _|_   __
//   | |/ _ \ \/ / __|| | \ \ / /
//   | |  __/>  <| |_ | |  \ V /
//   |_|\___/_/\_\\__||_|   \_/
// Author: Love Billenius <lovebillenius@disroot.org>
// License: GPL-3

#pragma once

#include <string>
#include <cstdint>

/**
 * @brief String utility functions.
 */
namespace string_utils {

    /**
     * @brief Checks if a given string consists solely of whitespace characters.
     *
     * @param str The string to check.
     * @return true If all characters in the string are whitespace.
     * @return false Otherwise.
     */
    bool is_all_whitespace(const std::string& str);

    /**
     * @brief Removes trailing whitespace lines from the given string.
     *
     * This function removes all consecutive empty or whitespace-only lines at the end
     * of the input string.
     *
     * @param str The string from which to remove trailing whitespace lines.
     */
    void remove_trailing_whitespace(std::string& str);

    /**
     * @brief Removes all tab characters from the given string.
     *
     * @param str The string from which to remove tab characters.
     */
    void remove_tabs(std::string& str);

    /**
     * @brief Limits the number of consecutive whitespace lines in the given string.
     *
     * This function ensures that no more than a specified number of consecutive empty
     * or whitespace-only lines exist in the string.
     *
     * @param str The string to process.
     * @param maxWhitespace The maximum allowed consecutive whitespace lines.
     */
    void limit_consecutive_whitespace(std::string& str, uint_fast8_t maxWhitespace);

}
